@@ -1,10 +1,9 @@
-ellipse3d <- function (x, ...) 
+ellipse3d <- function(x, ...) 
   UseMethod("ellipse3d")
 
 ellipse3d.default <-
-  function (x, scale = c(1, 1, 1), centre = c(0, 0, 0), level = 0.95, 
-            t = sqrt(qchisq(level, 3)), which = 1:3, subdivide = 3, smooth = TRUE, ...) 
-{
+  function(x, scale = c(1, 1, 1), centre = c(0, 0, 0), level = 0.95, 
+            t = sqrt(qchisq(level, 3)), which = 1:3, subdivide = 3, smooth = TRUE, ...) {
   stopifnot(is.matrix(x))
   
   cov <- x[which, which]
@@ -27,9 +26,8 @@ ellipse3d.default <-
 }
 
 ellipse3d.lm <-
-  function (x, which = 1:3, level = 0.95, t = sqrt(3 * qf(level, 
-                                                3, x$df.residual)), ...) 
-{
+  function(x, which = 1:3, level = 0.95, t = sqrt(3 * qf(level, 
+                                                3, x$df.residual)), ...) {
   s <- summary(x)  
   names <- names(x$coefficients[which])
   structure(c(ellipse3d.default(s$sigma^2 * s$cov.unscaled[which, which], 
@@ -37,8 +35,7 @@ ellipse3d.lm <-
               xlab=names[1], ylab=names[2], zlab=names[3]), class="mesh3d")
 }
 
-ellipse3d.glm <- function (x, which = 1:3, level = 0.95, t, dispersion, ...) 
-{
+ellipse3d.glm <- function(x, which = 1:3, level = 0.95, t, dispersion, ...) {
   s <- summary(x)
   est.disp <- missing(dispersion) & !(x$family$family %in% c('poisson','binomial'))
   if (missing(dispersion)) dispersion <- s$dispersion
@@ -51,13 +48,11 @@ ellipse3d.glm <- function (x, which = 1:3, level = 0.95, t, dispersion, ...)
               xlab=names[1], ylab=names[2], zlab=names[3]), class="mesh3d")
 }
 
-ellipse3d.nls <- function (x, which = 1:3, level = 0.95, t = sqrt(3 * qf(level, 
-                                                3, s$df[2])), ...) 
-{
+ellipse3d.nls <- function(x, which = 1:3, level = 0.95, t = sqrt(3 * qf(level, 
+                                                3, s$df[2])), ...) {
   s <- summary(x)  
   names <- names(x$m$getPars()[which])
   structure(c(ellipse3d.default(s$sigma^2 * s$cov.unscaled[which, which], 
                   centre = x$m$getPars()[which], t = t, ...),
 	      xlab=names[1], ylab=names[2], zlab=names[3]), class="mesh3d")                  
 }
-
